@@ -8,11 +8,9 @@
 #' @param label A character string naming the study area.
 #' @param res A character string representing the desired resolution of the NED. '1'
 #' indicates the 1 arc-second NED (the default), while '13' indicates the 1/3 arc-second dataset.
-#' @param raw.dir A character string indicating where raw downloaded files should be put.
-#' The directory will be created if missing. Defaults to './RAW/NED/'.
 #' @param extraction.dir A character string indicating where the extracted and cropped DEM should be put.
-#' The directory will be created if missing. Defaults to './EXTRACTIONS/NED/'.
-#' @param raster.options a vector of options for raster::writeRaster.
+#' The directory will be created if missing.
+#' @param raster.options a vector of options for terra::writeRaster.
 #' @param force.redo If an extraction for this template and label already exists, should a new one be created?
 #' @return A \code{RasterLayer} DEM cropped to the extent of the template.
 #' @export
@@ -29,21 +27,26 @@
 get_ned <- function(template,
                     label,
                     res = "1",
-                    raw.dir = paste0(tempdir(), "/FedData/raw/ned"),
-                    extraction.dir = paste0(tempdir(), "/FedData/extractions/ned/", label, "/"),
+                    extraction.dir = file.path(
+                      tempdir(),
+                      "FedData",
+                      "extractions",
+                      "ned",
+                      label
+                    ),
                     raster.options = c(
                       "COMPRESS=DEFLATE",
                       "ZLEVEL=9"
                     ),
-                    force.redo = F) {
-  raw.dir <- normalizePath(paste0(raw.dir, "/."), mustWork = FALSE)
-  extraction.dir <- normalizePath(paste0(extraction.dir, "/."), mustWork = FALSE)
+                    force.redo = FALSE) {
+  extraction.dir <- normalizePath(extraction.dir, mustWork = FALSE)
 
-  dir.create(raw.dir, showWarnings = FALSE, recursive = TRUE)
   dir.create(extraction.dir, showWarnings = FALSE, recursive = TRUE)
 
-  if (file.exists(paste0(extraction.dir, "/", label, "_NED_", res, ".tif")) & !force.redo) {
-    extracted.DEM <- raster::raster(paste0(extraction.dir, "/", label, "_NED_", res, ".tif"))
+  out_file <- paste0(label, "_NED_", res, ".tif")
+
+  if (file.exists(file.path(extraction.dir, out_file)) & !force.redo) {
+    extracted.DEM <- raster::raster(file.path(extraction.dir, out_file))
     return(extracted.DEM)
   }
 
@@ -75,8 +78,7 @@ get_ned <- function(template,
               template = template,
               res = res,
               tileNorthing = tilesLocations[loc, 1],
-              tileWesting = tilesLocations[loc, 2],
-              raw.dir = raw.dir
+              tileWesting = tilesLocations[loc, 2]
             ),
             error = function(e) {
               message("WARNING: ", e$message)
@@ -89,7 +91,8 @@ get_ned <- function(template,
     )
 
   if (all(sapply(tiles, is.null))) {
-    stop("No NED tiles are available for your study area. Please check your input data and internet connection.")
+    stop("No NED tiles are available for your study area.
+         Please check your input data and internet connection.")
   }
   tiles <- tiles[which(!sapply(tiles, is.null))]
 
@@ -109,14 +112,14 @@ get_ned <- function(template,
   }
 
   tiles %>%
+    terra::rast() %>%
     terra::crop(.,
       sf::st_transform(template, sf::st_crs(raster::crs(.))),
       snap = "out",
-      filename = paste(extraction.dir, "/", label, "_NED_", res, ".tif", sep = ""),
+      filename = file.path(extraction.dir, out_file),
       datatype = "FLT4S",
-      options = raster.options,
-      overwrite = T,
-      setStatistics = FALSE
+      gdal = raster.options,
+      overwrite = T
     )
 }
 
@@ -133,25 +136,23 @@ get_ned <- function(template,
 #' be downloaded.
 #' @param tileWesting An integer representing the westing (longitude, in degrees west of the prime meridian) of the northwest corner of the tile to
 #' be downloaded.
-#' @param raw.dir A character string indicating where raw downloaded files should be put.
-#' The directory will be created if missing. Defaults to './RAW/NED/'.
 #' @return A \code{RasterLayer} cropped within the specified \code{template}.
 #' @export
 #' @importFrom magrittr %>%
 #' @keywords internal
-get_ned_tile <- function(template = NULL, res = "1", tileNorthing, tileWesting, raw.dir) {
-  tmpdir <- tempfile()
-  if (!dir.create(tmpdir)) {
-    stop("failed to create my temporary directory")
-  }
-
+get_ned_tile <- function(template = NULL, res = "1", tileNorthing, tileWesting) {
   message("(Down)Loading NED tile for ", tileNorthing, "N and ", tileWesting, "W.")
 
   tileWesting <- formatC(tileWesting, width = 3, format = "d", flag = "0")
   tileNorthing <- formatC(tileNorthing, width = 2, format = "d", flag = "0")
 
   url <- paste0(
-    "/vsicurl/https://prd-tnm.s3.amazonaws.com/StagedProducts/Elevation/", res, "/TIFF/current/n", tileNorthing, "w", tileWesting, "/USGS_", res, "_n", tileNorthing, "w", tileWesting,
+    "/vsicurl/https://prd-tnm.s3.amazonaws.com/StagedProducts/Elevation/", res,
+    "/TIFF/current/n", tileNorthing,
+    "w", tileWesting,
+    "/USGS_", res,
+    "_n", tileNorthing,
+    "w", tileWesting,
     ".tif"
   )
 
